==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ExternalIPPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ExternalIPPolicyFluentImpl<A extends io.fabric8.openshift.api.model.ExternalIPPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ExternalIPPolicyFluent<A>{
  public ExternalIPPolicyFluentImpl() {
  }
  public ExternalIPPolicyFluentImpl(io.fabric8.openshift.api.model.ExternalIPPolicy instance) {
    this.withAllowedCIDRs(instance.getAllowedCIDRs()); 
    this.withRejectedCIDRs(instance.getRejectedCIDRs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> allowedCIDRs = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> rejectedCIDRs = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAllowedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.allowedCIDRs.add(index, item);
    return (A)this;
  }
  public A setToAllowedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.allowedCIDRs.set(index, item); return (A)this;
  }
  public A addToAllowedCIDRs(java.lang.String... items) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedCIDRs.add(item);} return (A)this;
  }
  public A addAllToAllowedCIDRs(java.util.Collection<java.lang.String> items) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedCIDRs.add(item);} return (A)this;
  }
  public A removeFromAllowedCIDRs(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.allowedCIDRs!= null){ this.allowedCIDRs.remove(item);}} return (A)this;
  }
  public A removeAllFromAllowedCIDRs(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.allowedCIDRs!= null){ this.allowedCIDRs.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAllowedCIDRs() {
    return this.allowedCIDRs;
  }
  public java.lang.String getAllowedCIDR(java.lang.Integer index) {
    return this.allowedCIDRs.get(index);
  }
  public java.lang.String getFirstAllowedCIDR() {
    return this.allowedCIDRs.get(0);
  }
  public java.lang.String getLastAllowedCIDR() {
    return this.allowedCIDRs.get(allowedCIDRs.size() - 1);
  }
  public java.lang.String getMatchingAllowedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedCIDRs) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAllowedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedCIDRs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAllowedCIDRs(java.util.List<java.lang.String> allowedCIDRs) {
    if (allowedCIDRs != null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : allowedCIDRs){this.addToAllowedCIDRs(item);}} else { this.allowedCIDRs = null;} return (A) this;
  }
  public A withAllowedCIDRs(java.lang.String... allowedCIDRs) {
    if (this.allowedCIDRs != null) {this.allowedCIDRs.clear();}
    if (allowedCIDRs != null) {for (java.lang.String item :allowedCIDRs){ this.addToAllowedCIDRs(item);}} return (A) this;
  }
  public java.lang.Boolean hasAllowedCIDRs() {
    return allowedCIDRs != null && !allowedCIDRs.isEmpty();
  }
  public A addNewAllowedCIDR(java.lang.String arg0) {
    return (A)addToAllowedCIDRs(new String(arg0));
  }
  public A addToRejectedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.rejectedCIDRs.add(index, item);
    return (A)this;
  }
  public A setToRejectedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.rejectedCIDRs.set(index, item); return (A)this;
  }
  public A addToRejectedCIDRs(java.lang.String... items) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.rejectedCIDRs.add(item);} return (A)this;
  }
  public A addAllToRejectedCIDRs(java.util.Collection<java.lang.String> items) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.rejectedCIDRs.add(item);} return (A)this;
  }
  public A removeFromRejectedCIDRs(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.rejectedCIDRs!= null){ this.rejectedCIDRs.remove(item);}} return (A)this;
  }
  public A removeAllFromRejectedCIDRs(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.rejectedCIDRs!= null){ this.rejectedCIDRs.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getRejectedCIDRs() {
    return this.rejectedCIDRs;
  }
  public java.lang.String getRejectedCIDR(java.lang.Integer index) {
    return this.rejectedCIDRs.get(index);
  }
  public java.lang.String getFirstRejectedCIDR() {
    return this.rejectedCIDRs.get(0);
  }
  public java.lang.String getLastRejectedCIDR() {
    return this.rejectedCIDRs.get(rejectedCIDRs.size() - 1);
  }
  public java.lang.String getMatchingRejectedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: rejectedCIDRs) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingRejectedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: rejectedCIDRs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRejectedCIDRs(java.util.List<java.lang.String> rejectedCIDRs) {
    if (rejectedCIDRs != null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : rejectedCIDRs){this.addToRejectedCIDRs(item);}} else { this.rejectedCIDRs = null;} return (A) this;
  }
  public A withRejectedCIDRs(java.lang.String... rejectedCIDRs) {
    if (this.rejectedCIDRs != null) {this.rejectedCIDRs.clear();}
    if (rejectedCIDRs != null) {for (java.lang.String item :rejectedCIDRs){ this.addToRejectedCIDRs(item);}} return (A) this;
  }
  public java.lang.Boolean hasRejectedCIDRs() {
    return rejectedCIDRs != null && !rejectedCIDRs.isEmpty();
  }
  public A addNewRejectedCIDR(java.lang.String arg0) {
    return (A)addToRejectedCIDRs(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExternalIPPolicyFluentImpl that = (ExternalIPPolicyFluentImpl) o;
    if (allowedCIDRs != null ? !allowedCIDRs.equals(that.allowedCIDRs) :that.allowedCIDRs != null) return false;
    if (rejectedCIDRs != null ? !rejectedCIDRs.equals(that.rejectedCIDRs) :that.rejectedCIDRs != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedCIDRs,  rejectedCIDRs,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ExternalIPPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ExternalIPPolicyFluentImpl<A extends io.fabric8.openshift.api.model.ExternalIPPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ExternalIPPolicyFluent<A>{
  public ExternalIPPolicyFluentImpl() {
  }
  public ExternalIPPolicyFluentImpl(io.fabric8.openshift.api.model.ExternalIPPolicy instance) {
    this.withAllowedCIDRs(instance.getAllowedCIDRs()); 
    this.withRejectedCIDRs(instance.getRejectedCIDRs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> allowedCIDRs = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> rejectedCIDRs = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAllowedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.allowedCIDRs.add(index, item);
    return (A)this;
  }
  public A setToAllowedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.allowedCIDRs.set(index, item); return (A)this;
  }
  public A addToAllowedCIDRs(java.lang.String... items) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedCIDRs.add(item);} return (A)this;
  }
  public A addAllToAllowedCIDRs(java.util.Collection<java.lang.String> items) {
    if (this.allowedCIDRs == null) {this.allowedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.allowedCIDRs.add(item);} return (A)this;
  }
  public A removeFromAllowedCIDRs(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.allowedCIDRs!= null){ this.allowedCIDRs.remove(item);}} return (A)this;
  }
  public A removeAllFromAllowedCIDRs(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.allowedCIDRs!= null){ this.allowedCIDRs.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAllowedCIDRs() {
    return this.allowedCIDRs;
  }
  public java.lang.String getAllowedCIDR(java.lang.Integer index) {
    return this.allowedCIDRs.get(index);
  }
  public java.lang.String getFirstAllowedCIDR() {
    return this.allowedCIDRs.get(0);
  }
  public java.lang.String getLastAllowedCIDR() {
    return this.allowedCIDRs.get(allowedCIDRs.size() - 1);
  }
  public java.lang.String getMatchingAllowedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedCIDRs) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAllowedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: allowedCIDRs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAllowedCIDRs(java.util.List<java.lang.String> allowedCIDRs) {
    if (allowedCIDRs != null) {this.allowedCIDRs = new java.util.ArrayList(); for (java.lang.String item : allowedCIDRs){this.addToAllowedCIDRs(item);}} else { this.allowedCIDRs = null;} return (A) this;
  }
  public A withAllowedCIDRs(java.lang.String... allowedCIDRs) {
    if (this.allowedCIDRs != null) {this.allowedCIDRs.clear();}
    if (allowedCIDRs != null) {for (java.lang.String item :allowedCIDRs){ this.addToAllowedCIDRs(item);}} return (A) this;
  }
  public java.lang.Boolean hasAllowedCIDRs() {
    return allowedCIDRs != null && !allowedCIDRs.isEmpty();
  }
  public A addNewAllowedCIDR(java.lang.String arg0) {
    return (A)addToAllowedCIDRs(new String(arg0));
  }
  public A addToRejectedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.rejectedCIDRs.add(index, item);
    return (A)this;
  }
  public A setToRejectedCIDRs(java.lang.Integer index,java.lang.String item) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    this.rejectedCIDRs.set(index, item); return (A)this;
  }
  public A addToRejectedCIDRs(java.lang.String... items) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.rejectedCIDRs.add(item);} return (A)this;
  }
  public A addAllToRejectedCIDRs(java.util.Collection<java.lang.String> items) {
    if (this.rejectedCIDRs == null) {this.rejectedCIDRs = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.rejectedCIDRs.add(item);} return (A)this;
  }
  public A removeFromRejectedCIDRs(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.rejectedCIDRs!= null){ this.rejectedCIDRs.remove(item);}} return (A)this;
  }
  public A removeAllFromRejectedCIDRs(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.rejectedCIDRs!= null){ this.rejectedCIDRs.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getRejectedCIDRs() {
    return this.rejectedCIDRs;
  }
  public java.lang.String getRejectedCIDR(java.lang.Integer index) {
    return this.rejectedCIDRs.get(index);
  }
  public java.lang.String getFirstRejectedCIDR() {
    return this.rejectedCIDRs.get(0);
  }
  public java.lang.String getLastRejectedCIDR() {
    return this.rejectedCIDRs.get(rejectedCIDRs.size() - 1);
  }
  public java.lang.String getMatchingRejectedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: rejectedCIDRs) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingRejectedCIDR(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: rejectedCIDRs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRejectedCIDRs(java.util.List<java.lang.String> rejectedCIDRs) {
    if (rejectedCIDRs != null) {this.rejectedCIDRs = new java.util.ArrayList(); for (java.lang.String item : rejectedCIDRs){this.addToRejectedCIDRs(item);}} else { this.rejectedCIDRs = null;} return (A) this;
  }
  public A withRejectedCIDRs(java.lang.String... rejectedCIDRs) {
    if (this.rejectedCIDRs != null) {this.rejectedCIDRs.clear();}
    if (rejectedCIDRs != null) {for (java.lang.String item :rejectedCIDRs){ this.addToRejectedCIDRs(item);}} return (A) this;
  }
  public java.lang.Boolean hasRejectedCIDRs() {
    return rejectedCIDRs != null && !rejectedCIDRs.isEmpty();
  }
  public A addNewRejectedCIDR(java.lang.String arg0) {
    return (A)addToRejectedCIDRs(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExternalIPPolicyFluentImpl that = (ExternalIPPolicyFluentImpl) o;
    if (allowedCIDRs != null ? !allowedCIDRs.equals(that.allowedCIDRs) :that.allowedCIDRs != null) return false;
    if (rejectedCIDRs != null ? !rejectedCIDRs.equals(that.rejectedCIDRs) :that.rejectedCIDRs != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedCIDRs,  rejectedCIDRs,  additionalProperties,  super.hashCode());
  }
  
}
